@@ -1,7 +1,7 @@
 package Finance::Robinhood::Order;
 use 5.010;
 use Carp;
-our $VERSION = "0.16";
+our $VERSION = "0.17";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -37,7 +37,7 @@ around BUILDARGS => sub {
             'POST',
             Finance::Robinhood::endpoint('orders'),
             {account    => {@args}->{account}->_get_url(),
-             instrument => {@args}->{instrument}->_get_url(),
+             instrument => {@args}->{instrument}->url(),
              symbol     => {@args}->{instrument}->symbol(),
              (map {
                   {@args}
